import React from 'react';
import JsBarcode from 'jsbarcode';
import styles from '../index.less';

/**
 * -2 条形码
 * -1 常量
 * 0  文字
 * 1 时间
 * 2 照片
 * */

const normalTextRender = (text, config) => {
  if (!text) {
    return null;
  }
  const style = {
    fontSize: `${config.fieldFontSize || 16}px`, // 默认 16px
    fontFamily: `${config.fieldFont || '黑体'}`, // 默认黑体
  };
  return <span style={style}>
    {text}
  </span>;
};


class BarCode extends React.Component {
  componentDidMount() {
    this.toJsBarcode();
  }

  toJsBarcode() {
    // 调用 JsBarcode方法生成条形码
    JsBarcode(this.barcode, this.props.value || '1234567890', {
      text: '',
      format: 'CODE39',
      displayValue: false,
      width: 1.0,
      height: 30,
      margin: 0,
    });
  }

  render() {
    return (
      <div className="barcode-box">
        <svg
          ref={(ref) => {
            this.barcode = ref;
          }}
        />
      </div>
    );
  }
}


export default function DetailDom({ config, data }) {
  const { x, y, fieldCode } = config;
  const outSideDom = (children) => {
    return (
      <div
        className={styles.inSideItemPrint}
        key={fieldCode}
        style={{
          left: x + 'px',
          top: y + 'px',
        }}>
        {children}
      </div>
    );
  };
  let children = null;
  switch (config.fieldType) {
    case '-2': // 条形码
      children = <BarCode value={data}/>;
      break;
    case '-1': // 常量
      children = normalTextRender(config.content, config);
      break;
    case '0': // 文字
      children = normalTextRender(data, config);
      break;
    case '1': // 时间
      children = normalTextRender(config.content, config);
      break;
    case '2': // 照片
      children = normalTextRender(config.content, config);
      break;
    default:
      children = normalTextRender(config.content, config);
      break;
  }
  return outSideDom(children);
}
